<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk_UK">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About </source>
        <translation>Про програму </translation>
    </message>
    <message>
        <source>About</source>
        <translation>Про програму</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Версія</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Автор</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Підтримати</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Зв&apos;язок</translation>
    </message>
</context>
<context>
    <name>AboutTab</name>
    <message>
        <source>License: </source>
        <translation>Ліцензія: </translation>
    </message>
    <message>
        <source>Screenshot and Annotation Tool</source>
        <translation>Програма для створення та анотування знімків вікон</translation>
    </message>
</context>
<context>
    <name>ActionSettingTab</name>
    <message>
        <source>Name</source>
        <translation>Назва</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Скорочення</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Очистити</translation>
    </message>
    <message>
        <source>Take Capture</source>
        <translation>Зробити знімок</translation>
    </message>
    <message>
        <source>Include Cursor</source>
        <translation>Разом із вказівником</translation>
    </message>
    <message>
        <source>Delay</source>
        <translation>Затримка</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>с</translation>
    </message>
    <message>
        <source>Capture Mode</source>
        <translation>Режим знімання</translation>
    </message>
    <message>
        <source>Show image in Pin Window</source>
        <translation>Показати зображення у пришпиленому вікні</translation>
    </message>
    <message>
        <source>Copy image to Clipboard</source>
        <translation>Копіювати зображення до буфера обміну даними</translation>
    </message>
    <message>
        <source>Upload image</source>
        <translation>Вивантажити зображення</translation>
    </message>
    <message>
        <source>Open image parent directory</source>
        <translation>Відкрити зображення у батьківському каталозі</translation>
    </message>
    <message>
        <source>Save image</source>
        <translation>Зберегти зображення</translation>
    </message>
    <message>
        <source>Hide Main Window</source>
        <translation>Приховати головне вікно</translation>
    </message>
</context>
<context>
    <name>ActionsSettings</name>
    <message>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <source>Actions Settings</source>
        <translation>Параметри дій</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Дія</translation>
    </message>
</context>
<context>
    <name>AddWatermarkOperation</name>
    <message>
        <source>Watermark Image Required</source>
        <translation>Потрібне зображення водяного знаку</translation>
    </message>
    <message>
        <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
        <translation>Будь ласка, додайте водяний знак за допомогою пункту Параметри → Налаштування → Анотатор → Оновити</translation>
    </message>
</context>
<context>
    <name>AnnotationSettings</name>
    <message>
        <source>Smooth Painter Paths</source>
        <translation>Згладжувати намальовані контури</translation>
    </message>
    <message>
        <source>When enabled smooths out pen and
marker paths after finished drawing.</source>
        <translation>Якщо позначено, згладжувати лінії, які намальовано
пером або маркером, після завершення малювання.</translation>
    </message>
    <message>
        <source>Smooth Factor</source>
        <translation>Коефіцієнт згладжування</translation>
    </message>
    <message>
        <source>Increasing the smooth factor will decrease
precision for pen and marker but will
make them more smooth.</source>
        <translation>Збільшення коефіцієнта згладжування зменшить чіткість
ліній, залишених пером чи маркером, але зробить їх 
плавнішими.</translation>
    </message>
    <message>
        <source>Annotator Settings</source>
        <translation>Налаштування анотатора</translation>
    </message>
    <message>
        <source>Remember annotation tool selection and load on startup</source>
        <translation>Запам&apos;ятовувати вибраний засіб анотування і завантажувати його після запуску</translation>
    </message>
    <message>
        <source>Switch to Select Tool after drawing Item</source>
        <translation>Після малювання об&apos;єкта перемкнутися на засіб позначення</translation>
    </message>
    <message>
        <source>Number Tool Seed change updates all Number Items</source>
        <translation>Зміна у засобі перенумерування оновлює усі записи номерів</translation>
    </message>
    <message>
        <source>Disabling this option causes changes of the number tool
seed to affect only new items but not existing items.
Disabling this option allows having duplicate numbers.</source>
        <translation>Якщо цей пункт не буде позначено, зміни у засобі
нумерування стосуватимуться лише нових записів,
і не стосуватимуться наявних. Якщо пункт не буде
позначено, також можлива поява дублікатів номерів.</translation>
    </message>
    <message>
        <source>Canvas Color</source>
        <translation>Колір полотна</translation>
    </message>
    <message>
        <source>Default Canvas background color for annotation area.
Changing color affects only new annotation areas.</source>
        <translation>Типовий колір тла полотна для області анотацій.
Зміна кольору стосуватиметься лише нових областей анотацій.</translation>
    </message>
    <message>
        <source>Select Item after drawing</source>
        <translation>Позначити елемент після малювання</translation>
    </message>
    <message>
        <source>With this option enabled the item gets selected after
being created, allowing changing settings.</source>
        <translation>Якщо цей пункт буде позначено, програма позначатиме елемент
після його створення, надаючи змогу змінити його параметри.</translation>
    </message>
</context>
<context>
    <name>ApplicationSettings</name>
    <message>
        <source>Capture screenshot at startup with default mode</source>
        <translation>Захоплювати знімок після запуску у типовому режимі</translation>
    </message>
    <message>
        <source>Application Style</source>
        <translation>Стиль вікна програми</translation>
    </message>
    <message>
        <source>Sets the application style which defines the look and feel of the GUI.
Change requires ksnip restart to take effect.</source>
        <translation>Встановлює стиль вікна програми, який визначає її вигляд.
Щоб оформлення змінилося, перезапустіть ksnip.</translation>
    </message>
    <message>
        <source>Application Settings</source>
        <translation>Параметри програми</translation>
    </message>
    <message>
        <source>Automatically copy new captures to clipboard</source>
        <translation>Автоматично копіювати нові знімки до буферу обміну</translation>
    </message>
    <message>
        <source>Use Tabs</source>
        <translation>Використовувати вкладки</translation>
    </message>
    <message>
        <source>Change requires restart.</source>
        <translation>Набуття змінами чинності потребує перезапуску.</translation>
    </message>
    <message>
        <source>Run ksnip as single instance</source>
        <translation>Запускати ksnip у режимі єдиного екземпляра</translation>
    </message>
    <message>
        <source>Hide Tabbar when only one Tab is used.</source>
        <translation>Ховати панель вкладок, якщо використано лише одну вкладку.</translation>
    </message>
    <message>
        <source>Enabling this option will allow only one ksnip instance to run,
all other instances started after the first will pass its
arguments to the first and close. Changing this option requires
a new start of all instances.</source>
        <translation>Якщо позначити цей пункт, запускатиметься лише один екземпляр ksnip.
Усі інші запущені екземпляри просто передаватимуть свої аргументи
першому екземпляру і завершуватимуть роботу. Зміна значення параметра
для набуття чинності потребуватиме перезапуску усіх екземплярів.</translation>
    </message>
    <message>
        <source>Remember Main Window position on move and load on startup</source>
        <translation>Запам&apos;ятати розташування головного вікна і відновлювати його після запуску</translation>
    </message>
    <message>
        <source>Auto hide Tabs</source>
        <translation>Автоматично ховати вкладки</translation>
    </message>
    <message>
        <source>Auto hide Docks</source>
        <translation>Автоматично ховати панелі</translation>
    </message>
    <message>
        <source>On startup hide Toolbar and Annotation Settings.
Docks visibility can be toggled with the Tab Key.</source>
        <translation>Після запуску приховати панель інструментів і параметри анотацій.
Видимістю бічних панелей можна керувати за допомогою клавіші Tab.</translation>
    </message>
    <message>
        <source>Auto resize to content</source>
        <translation>Автоматичний розмір за вмістом</translation>
    </message>
    <message>
        <source>Automatically resize Main Window to fit content image.</source>
        <translation>Автоматично змінювати розміри головного вікна за зображенням-вмістом.</translation>
    </message>
    <message>
        <source>Enable Debugging</source>
        <translation>Увімкнути діагностику</translation>
    </message>
    <message>
        <source>Enables debug output written to the console.
Change requires ksnip restart to take effect.</source>
        <translation>Вмикає діагностичне виведення до консолі.
Для набуття змінами чинності слід перезапустити ksnip.</translation>
    </message>
    <message>
        <source>Resize to content delay</source>
        <translation>Затримка зміни розмірів до вмісту</translation>
    </message>
    <message>
        <source>Resizing to content is delay to allow the Window Manager to receive
the new content. In case that the Main Windows is not adjusted correctly
to the new content, increasing this delay might improve the behavior.</source>
        <translation>Зміна розмірів за вмістом затримується з метою уможливлення для засобу
керування вікнами отримання нового вмісту. Якщо головне вікно не
коригується за новим вмістом, збільшення затримки може поліпшити ситуацію.</translation>
    </message>
</context>
<context>
    <name>AuthorTab</name>
    <message>
        <source>Contributors:</source>
        <translation>Учасники розробки:</translation>
    </message>
    <message>
        <source>Spanish Translation</source>
        <translation>Переклад іспанською</translation>
    </message>
    <message>
        <source>Dutch Translation</source>
        <translation>Переклад голландською</translation>
    </message>
    <message>
        <source>Russian Translation</source>
        <translation>Переклад російською</translation>
    </message>
    <message>
        <source>Norwegian Bokmål Translation</source>
        <translation>Переклад норвезькою (букмол)</translation>
    </message>
    <message>
        <source>French Translation</source>
        <translation>Переклад французькою</translation>
    </message>
    <message>
        <source>Polish Translation</source>
        <translation>Переклад польською</translation>
    </message>
    <message>
        <source>Snap &amp; Flatpak Support</source>
        <translation>Підтримка Snap &amp; Flatpak</translation>
    </message>
    <message>
        <source>The Authors:</source>
        <translation>Автори:</translation>
    </message>
</context>
<context>
    <name>CanDiscardOperation</name>
    <message>
        <source>Warning - </source>
        <translation>Попередження — </translation>
    </message>
    <message>
        <source>The capture %1%2%3 has been modified.
Do you want to save it?</source>
        <translation>Захоплене зображення %1%2%3 було змінено.
Хочете його зберегти?</translation>
    </message>
</context>
<context>
    <name>CaptureModePicker</name>
    <message>
        <source>New</source>
        <translation>Створити</translation>
    </message>
    <message>
        <source>Draw a rectangular area with your mouse</source>
        <translation>Виділіть мишкою прямокутну область</translation>
    </message>
    <message>
        <source>Capture full screen including all monitors</source>
        <translation>Зробити знімок усього екрана з усіх моніторів</translation>
    </message>
    <message>
        <source>Capture screen where the mouse is located</source>
        <translation>Зробити знімок екрана, на якому розташовано вказівник миші</translation>
    </message>
    <message>
        <source>Capture window that currently has focus</source>
        <translation>Зробити знімок сфокусованого вікна</translation>
    </message>
    <message>
        <source>Capture that is currently under the mouse cursor</source>
        <translation>Зробити знімок вікна, на якому розташовано вказівник миші</translation>
    </message>
    <message>
        <source>Capture a screenshot of the last selected rectangular area</source>
        <translation>Зробити знімок останньої позначеної прямокутної області</translation>
    </message>
    <message>
        <source>Uses the screenshot Portal for taking screenshot</source>
        <translation>Використовує портал знімків вікон для створення знімка</translation>
    </message>
</context>
<context>
    <name>ContactTab</name>
    <message>
        <source>Community</source>
        <translation>Спільнота</translation>
    </message>
    <message>
        <source>Bug Reports</source>
        <translation>Звіти щодо вад</translation>
    </message>
    <message>
        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
        <translation>Якщо у вас виникли питання загального характеру, ідеї, або ви просто хочете поговорити про ksnip,&lt;br/&gt;будь ласка, долучайтеся до нашого каналу %1 або нашого сервера %2.</translation>
    </message>
    <message>
        <source>Please use %1 to report bugs.</source>
        <translation>Будь ласка, скористайтеся сторінкою %1 для звітування щодо вад.</translation>
    </message>
</context>
<context>
    <name>CopyAsDataUriOperation</name>
    <message>
        <source>Failed to copy to clipboard</source>
        <translation>Не вдалося скопіювати до буфера</translation>
    </message>
    <message>
        <source>Failed to copy to clipboard as base64 encoded image.</source>
        <translation>Не вдалося скопіювати до буфера дані зображення у кодуванні base64.</translation>
    </message>
    <message>
        <source>Copied to clipboard</source>
        <translation>Скопійовано до буфера</translation>
    </message>
    <message>
        <source>Copied to clipboard as base64 encoded image.</source>
        <translation>Скопійовано до буфера як зображення у кодуванні base64.</translation>
    </message>
</context>
<context>
    <name>DeleteImageOperation</name>
    <message>
        <source>Delete Image</source>
        <translation>Вилучити зображення</translation>
    </message>
    <message>
        <source>The item &apos;%1&apos; will be deleted.
Do you want to continue?</source>
        <translation>Запис «%1» буде вилучено.
Хочете виконати цю дію?</translation>
    </message>
</context>
<context>
    <name>DonateTab</name>
    <message>
        <source>Donations are always welcome</source>
        <translation>Пожертви завжди вітаються</translation>
    </message>
    <message>
        <source>Donation</source>
        <translation>Пожертва</translation>
    </message>
    <message>
        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
        <translation>ksnip є неприбутковим вільним відкритим проєктом із розробки програмного забезпечення, але&lt;br/&gt;має певні супутні витрати,&lt;br/&gt;зокрема, має платити за домен та обладнання для підтримки роботи на багатьох апаратних платформах.</translation>
    </message>
    <message>
        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
        <translation>Якщо ви хочете допомогти або просто вважаєте за потрібне віддячити за виконану роботу,&lt;br/&gt;надавши розробникам можливість випити пива або кави, ви можете підтримати проєкт %1тут%2.</translation>
    </message>
    <message>
        <source>Become a GitHub Sponsor?</source>
        <translation>Станете спонсором GitHub?</translation>
    </message>
    <message>
        <source>Also possible, %1here%2.</source>
        <translation>Також можна підтримати %1тут%2.</translation>
    </message>
</context>
<context>
    <name>EmptyActionSettingTab</name>
    <message>
        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
        <translation>Нові дії можна додати натисканням кнопки «Додати».</translation>
    </message>
</context>
<context>
    <name>EnumTranslator</name>
    <message>
        <source>Rectangular Area</source>
        <translation>Прямокутна ділянка</translation>
    </message>
    <message>
        <source>Last Rectangular Area</source>
        <translation>Остання прямокутна ділянка</translation>
    </message>
    <message>
        <source>Full Screen (All Monitors)</source>
        <translation>Повноекранний режим (усі монітори)</translation>
    </message>
    <message>
        <source>Current Screen</source>
        <translation>Поточний екран</translation>
    </message>
    <message>
        <source>Active Window</source>
        <translation>Активне вікно</translation>
    </message>
    <message>
        <source>Window Under Cursor</source>
        <translation>Вікно під вказівником</translation>
    </message>
    <message>
        <source>Screenshot Portal</source>
        <translation>Портал знімків вікон</translation>
    </message>
</context>
<context>
    <name>FtpUploaderSettings</name>
    <message>
        <source>Force anonymous upload.</source>
        <translation>Примусове анонімне вивантаження.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Адреса</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>Вивантажувач FTP</translation>
    </message>
</context>
<context>
    <name>HandleUploadResultOperation</name>
    <message>
        <source>Upload Successful</source>
        <translation>Успішне вивантаження</translation>
    </message>
    <message>
        <source>Unable to save temporary image for upload.</source>
        <translation>Не вдалося зберегти тимчасове зображення для вивантаження.</translation>
    </message>
    <message>
        <source>Unable to start process, check path and permissions.</source>
        <translation>Не вдалося запустити процес. Перевірте шлях і права доступу.</translation>
    </message>
    <message>
        <source>Process crashed</source>
        <translation>Аварійне завершення процесу</translation>
    </message>
    <message>
        <source>Process timed out.</source>
        <translation>Перевищено час очікування на очікування даних від процесу.</translation>
    </message>
    <message>
        <source>Process read error.</source>
        <translation>Помилка під час читання даних з процесу.</translation>
    </message>
    <message>
        <source>Process write error.</source>
        <translation>Помилка під час спроби записати дані до процесу.</translation>
    </message>
    <message>
        <source>Web error, check console output.</source>
        <translation>Помилка із мережею, ознайомтеся із виведеними до консолі даними.</translation>
    </message>
    <message>
        <source>Upload Failed</source>
        <translation>Невдала спроба вивантаження</translation>
    </message>
    <message>
        <source>Script wrote to StdErr.</source>
        <translation>Скрипт записано до StdErr.</translation>
    </message>
    <message>
        <source>FTP Upload finished successfully.</source>
        <translation>Вивантаження на FTP успішно завершено.</translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation>Невідома помилка.</translation>
    </message>
    <message>
        <source>Connection Error.</source>
        <translation>Помилка з&apos;єднання.</translation>
    </message>
    <message>
        <source>Permission Error.</source>
        <translation>Помилка із правами доступу.</translation>
    </message>
    <message>
        <source>Upload script %1  finished successfully.</source>
        <translation>Скрипт вивантаження %1 завершив роботу успішно.</translation>
    </message>
    <message>
        <source>Uploaded to %1</source>
        <translation>Вивантажено до %1</translation>
    </message>
</context>
<context>
    <name>HotKeySettings</name>
    <message>
        <source>Enable Global HotKeys</source>
        <translation>Увімкнути глобальні гарячі клавіші</translation>
    </message>
    <message>
        <source>Capture Rect Area</source>
        <translation>Зняти прямокутну область</translation>
    </message>
    <message>
        <source>Capture Full Screen</source>
        <translation>Зняти весь екран</translation>
    </message>
    <message>
        <source>Capture current Screen</source>
        <translation>Зняти поточний екран</translation>
    </message>
    <message>
        <source>Capture active Window</source>
        <translation>Зняти активне вікно</translation>
    </message>
    <message>
        <source>Capture Window under Cursor</source>
        <translation>Зняти вікно під курсором</translation>
    </message>
    <message>
        <source>Global HotKeys</source>
        <translation>Глобальні гарячі клавіші</translation>
    </message>
    <message>
        <source>Capture Last Rect Area</source>
        <translation>Зняти останню прямокутну область</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Очистити</translation>
    </message>
    <message>
        <source>Capture using Portal</source>
        <translation>Захопити за допомогою порталу</translation>
    </message>
    <message>
        <source>HotKeys are currently supported only for Windows and X11.
Disabling this option makes also the action shortcuts ksnip only.</source>
        <translation>Підтримку клавіатурних скорочень у поточній версії передбачено лише для Windows і X11.
Зняття позначення з цього пункту обмежує клавіатурні скорочення лише ksnip.</translation>
    </message>
</context>
<context>
    <name>ImageGrabberSettings</name>
    <message>
        <source>Capture mouse cursor on screenshot</source>
        <translation>Показувати вказівник миші на знімку</translation>
    </message>
    <message>
        <source>Should mouse cursor be visible on
screenshots.</source>
        <translation>Чи має бути показано вказівник миші
на знімках.</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Захоплення знімків</translation>
    </message>
    <message>
        <source>Generic Wayland implementations that use
XDG-DESKTOP-PORTAL handle screen scaling
differently. Enabling this option will
determine the current screen scaling and
apply that to the screenshot in ksnip.</source>
        <translation>Типові реалізації Wayland, які використовують
XDG-DESKTOP-PORTAL, обробляють масштабування
екрана інакше. Вмикання цього параметра
призведе до визначення поточного масштабування
екрана і застосування його до знімка у ksnip.</translation>
    </message>
    <message>
        <source>GNOME and KDE Plasma support their own Wayland
and the Generic XDG-DESKTOP-PORTAL screenshots.
Enabling this option will force KDE Plasma and
GNOME to use the XDG-DESKTOP-PORTAL screenshots.
Change in this option require a ksnip restart.</source>
        <translation>У GNOME і Плазмі KDE передбачено власні засоби створення
знімків Wayland та типових знімків XDG-DESKTOP-PORTAL.
Якщо позначити цей пункт, програма примусово
використовуватиме у Плазмі KDE і GNOME знімки XDG-DESKTOP-PORTAL.
Для набуття чинності цим параметром ksnip слід перезапустити.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing screenshot</source>
        <translation>Показувати головне вікно після створення знімка</translation>
    </message>
    <message>
        <source>Hide Main Window during screenshot</source>
        <translation>Ховати головне вікно під час створення знімка</translation>
    </message>
    <message>
        <source>Hide Main Window when capturing a new screenshot.</source>
        <translation>Ховати головне вікно під час створення знімка.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing a new screenshot
when the Main Window was hidden or minimize.</source>
        <translation>Показати головне вікно після створення знімка,
якщо головне вікно було приховано або згорнуто.</translation>
    </message>
    <message>
        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
        <translation>Примусово типовий знімок вікна Wayland (xdg-desktop-portal)</translation>
    </message>
    <message>
        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
        <translation>Масштабовані загальні знімки вікон Wayland (xdg-desktop-portal)</translation>
    </message>
</context>
<context>
    <name>ImgurHistoryDialog</name>
    <message>
        <source>Imgur History</source>
        <translation>Історія завантажень</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <source>Time Stamp</source>
        <translation>Позначка часу</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Посилання</translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>Видалити посилання</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <source>Upload to imgur.com finished!</source>
        <translation>Вивантаження на imgur.com завершено!</translation>
    </message>
    <message>
        <source>Received new token, trying upload again…</source>
        <translation>Отримано новий жетон, спробуємо вивантажити ще раз…</translation>
    </message>
    <message>
        <source>Imgur token has expired, requesting new token…</source>
        <translation>Термін дії жетона Imgur вичерпано, надсилаємо запит щодо нового жетона…</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderSettings</name>
    <message>
        <source>Force anonymous upload</source>
        <translation>Примусове анонімне вивантаження</translation>
    </message>
    <message>
        <source>Always copy Imgur link to clipboard</source>
        <translation>Завжди копіювати посилання Imgur до буфера обміну даними</translation>
    </message>
    <message>
        <source>Client ID</source>
        <translation>Ід. клієнта</translation>
    </message>
    <message>
        <source>Client Secret</source>
        <translation>Закритий ключ клієнта</translation>
    </message>
    <message>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <source>Enter imgur Pin which will be exchanged for a token.</source>
        <translation>Вкажіть PIN-код imgur, який буде обміняно на жетон.</translation>
    </message>
    <message>
        <source>Get PIN</source>
        <translation>Отримати PIN-код</translation>
    </message>
    <message>
        <source>Get Token</source>
        <translation>Отримати жетон</translation>
    </message>
    <message>
        <source>Imgur History</source>
        <translation>Журнал Imgur</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Вивантажувач на Imgur</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>Waiting for imgur.com…</source>
        <translation>Очікування на imgur.com…</translation>
    </message>
    <message>
        <source>Imgur.com token successfully updated.</source>
        <translation>Жетор Imgur.com успішно оновлено.</translation>
    </message>
    <message>
        <source>Imgur.com token update error.</source>
        <translation>Помилка під час спроби оновити жетон Imgur.com.</translation>
    </message>
    <message>
        <source>After uploading open Imgur link in default browser</source>
        <translation>Після завантаження відкрити посилання на Imgur у браузері за замовчуванням</translation>
    </message>
    <message>
        <source>Link directly to image</source>
        <translation>Пряме посилання до зображення</translation>
    </message>
    <message>
        <source>Base Url:</source>
        <translation>Базова адреса:</translation>
    </message>
    <message>
        <source>Base url that will be used for communication with Imgur.
Changing requires restart.</source>
        <translation>Базова адреса, яку буде використано для обміну даними з Imgur.
Для набуття змінами чинності слід перезапустити програму.</translation>
    </message>
    <message>
        <source>Clear Token</source>
        <translation>Вилучити жетон</translation>
    </message>
</context>
<context>
    <name>LoadImageFromFileOperation</name>
    <message>
        <source>Unable to open image</source>
        <translation>Не вдалося відкрити зображення</translation>
    </message>
    <message>
        <source>Unable to open image from path %1</source>
        <translation>Не вдалося відкрити зображення зі шляхом %1</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>New</source>
        <translation>Створити</translation>
    </message>
    <message>
        <source>Delay in seconds between triggering
and capturing screenshot.</source>
        <translation>Затримка у секундах перед тим,
як буде зроблено знімок.</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>с</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <source>Save Screen Capture to file system</source>
        <translation>Зберегти знімок у файловій системі</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <source>Copy Screen Capture to clipboard</source>
        <translation>Копіювати знімок до буфера обміну</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Інструменти</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Повторити</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Обрізати</translation>
    </message>
    <message>
        <source>Crop Screen Capture</source>
        <translation>Обрізати захоплене з екрана</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Unsaved</source>
        <translation>Не збережений</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Завантажити</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Роздрукувати</translation>
    </message>
    <message>
        <source>Opens printer dialog and provide option to print image</source>
        <translation>Відкрити діалогове вікно з можливістю роздрукувати зображення</translation>
    </message>
    <message>
        <source>Print Preview</source>
        <translation>Перегляд друку</translation>
    </message>
    <message>
        <source>Opens Print Preview dialog where the image orientation can be changed</source>
        <translation>Відкрити попередній перегляд роздруківки, в якому можна змінити орієнтацію зображення</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Розмір</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Параметри</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Про програму</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Відкрити</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Правка</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Налаштування</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Довідка</translation>
    </message>
    <message>
        <source>Add Watermark</source>
        <translation>Додати водяний знак</translation>
    </message>
    <message>
        <source>Add Watermark to captured image. Multiple watermarks can be added.</source>
        <translation>Додати водяний знак до знімка. Можна додати декілька знаків.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>Unable to show image</source>
        <translation>Не вдається показати зображення</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Зберегти як…</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Вставити</translation>
    </message>
    <message>
        <source>Paste Embedded</source>
        <translation>Вставити вбудованим</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Пришпилити</translation>
    </message>
    <message>
        <source>Pin screenshot to foreground in frameless window</source>
        <translation>Пришпилити знімок вікна до переднього плану у вікні без рамки</translation>
    </message>
    <message>
        <source>No image provided but one was expected.</source>
        <translation>Не надано зображення, хоча програма його очікувала.</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Копіювати шлях</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Відкрити каталог</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>П&amp;ерегляд</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Перейменувати</translation>
    </message>
    <message>
        <source>Open Images</source>
        <translation>Відкрити зображення</translation>
    </message>
    <message>
        <source>Show Docks</source>
        <translation>Показати бічні панелі</translation>
    </message>
    <message>
        <source>Hide Docks</source>
        <translation>Приховати бічні панелі</translation>
    </message>
    <message>
        <source>Copy as data URI</source>
        <translation>Копіювати як адресу даних</translation>
    </message>
    <message>
        <source>Open &amp;Recent</source>
        <translation>Відкрити &amp;нещодавні</translation>
    </message>
    <message>
        <source>Modify Canvas</source>
        <translation>Змінити полотно</translation>
    </message>
    <message>
        <source>Upload triggerCapture to external source</source>
        <translation>Вивантажити triggerCapture на зовнішнє джерело</translation>
    </message>
    <message>
        <source>Copy triggerCapture to system clipboard</source>
        <translation>Скопіювати triggerCapture до буфера обміну даними системи</translation>
    </message>
    <message>
        <source>Scale Image</source>
        <translation>Масштабувати зображення</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Обертати</translation>
    </message>
    <message>
        <source>Rotate Image</source>
        <translation>Обертати зображення</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Дії</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>файли зображень</translation>
    </message>
</context>
<context>
    <name>MultiCaptureHandler</name>
    <message>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Зберегти як</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Відкрити каталог</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Копіювати шлях</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Перейменувати</translation>
    </message>
</context>
<context>
    <name>NewCaptureNameProvider</name>
    <message>
        <source>Capture</source>
        <translation>Захопити</translation>
    </message>
</context>
<context>
    <name>PinWindow</name>
    <message>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Закрити інші</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Закрити всі</translation>
    </message>
</context>
<context>
    <name>PinWindowHandler</name>
    <message>
        <source>Pin Window %1</source>
        <translation>Пришпилити вікно %1</translation>
    </message>
</context>
<context>
    <name>RenameOperation</name>
    <message>
        <source>Image Renamed</source>
        <translation>Зображення перейменовано</translation>
    </message>
    <message>
        <source>Image Rename Failed</source>
        <translation>Не вдалося перейменувати зображення</translation>
    </message>
    <message>
        <source>Rename image</source>
        <translation>Перейменувати зображення</translation>
    </message>
    <message>
        <source>New filename:</source>
        <translation>Нова назва файла:</translation>
    </message>
    <message>
        <source>Successfully renamed image to %1</source>
        <translation>Зображення успішно перейменовано на %1</translation>
    </message>
    <message>
        <source>Failed to rename image to %1</source>
        <translation>Не вдалося перейменувати зображення на %1</translation>
    </message>
</context>
<context>
    <name>SaveOperation</name>
    <message>
        <source>Save As</source>
        <translation>Зберегти як</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>усі файли</translation>
    </message>
    <message>
        <source>Image Saved</source>
        <translation>Зображення збережено</translation>
    </message>
    <message>
        <source>Saving Image Failed</source>
        <translation>Не вдалося зберегти зображення</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>файли зображень</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Збережено до %1</translation>
    </message>
    <message>
        <source>Failed to save image to %1</source>
        <translation>Не вдалося зберегти зображення до %1</translation>
    </message>
</context>
<context>
    <name>SaverSettings</name>
    <message>
        <source>Automatically save new captures to default location</source>
        <translation>Автоматично зберігати нові знімки до типової теки</translation>
    </message>
    <message>
        <source>Prompt to save before discarding unsaved changes</source>
        <translation>Питати, чи бажаєте зберегти зміни до зображення, перш ніж їх відкидати</translation>
    </message>
    <message>
        <source>Remember last Save Directory</source>
        <translation>Запам&apos;ятовувати останній каталог зберігання</translation>
    </message>
    <message>
        <source>When enabled will overwrite the save directory stored in settings
with the latest save directory, for every save.</source>
        <translation>Якщо позначено, програма перезаписуватиме каталог зберігання
знімків у параметрах останнім каталогом зберігання під час кожного збереження знімка.</translation>
    </message>
    <message>
        <source>Capture save location and filename</source>
        <translation>Місце автоматичного збереження та формат назви знімків</translation>
    </message>
    <message>
        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
Filename can contain following wildcards:
- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
        <translation>Підтримуваними форматами є JPG, PNG і BMP. Якщо формат не вказано, типово буде використано PNG.
Шаблон може включати такі рядки-замінники:
- $Y (рік), $M (місяць), $D (день) для дати, $h (години), $m (хвилини), $s (секунди) для часу або $T для часу у форматі ггххсс.
- Декілька послідовних # для лічильника. #### дасть нумерацію 0001, далі 0002 тощо.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Вибрати</translation>
    </message>
    <message>
        <source>Saver Settings</source>
        <translation>Параметри засобу зберігання</translation>
    </message>
    <message>
        <source>Capture save location</source>
        <translation>Місце збереження знімків</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Типові</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Коефіцієнт</translation>
    </message>
    <message>
        <source>Save Quality</source>
        <translation>Якість збереження</translation>
    </message>
    <message>
        <source>Specify 0 to obtain small compressed files, 100 for large uncompressed files.
Not all image formats support the full range, JPEG does.</source>
        <translation>Вкажіть 0 для отримання малих стиснених файлів або 100 для отримання великих файлів без стискання.
Повний діапазон коефіцієнтів стискання передбачено не усіма форматами, але його підтримку передбачено у JPEG.</translation>
    </message>
</context>
<context>
    <name>ScriptUploaderSettings</name>
    <message>
        <source>Copy script output to clipboard</source>
        <translation>Копіювати виведення скрипту до буфера обміну</translation>
    </message>
    <message>
        <source>Script:</source>
        <translation>Скрипт:</translation>
    </message>
    <message>
        <source>Path to script that will be called for uploading. During upload the script will be called
with the path to a temporary png file as a single argument.</source>
        <translation>Шлях до скрипту, який буде викликано для вивантаження даних. Під час вивантаження
скрипт буде викликано із параметром шляху до тимчасового файла png як єдиним аргументом.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Вибрати</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Вивантажувач скриптів</translation>
    </message>
    <message>
        <source>Select Upload Script</source>
        <translation>Виберіть скрипт для вивантаження</translation>
    </message>
    <message>
        <source>Stop when upload script writes to StdErr</source>
        <translation>Зупиняти обробку, якщо скрипт виведення записує щось до StdErr</translation>
    </message>
    <message>
        <source>Marks the upload as failed when script writes to StdErr.
Without this setting errors in the script will be unnoticed.</source>
        <translation>Позначати вивантаження як невдале, якщо скрипт записує щось до StdErr.
Якщо пункт не позначено, програма не братиме до уваги повідомлення про помилки, які виведено скриптом.</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Фільтр:</translation>
    </message>
    <message>
        <source>RegEx Expression. Only copy to clipboard what matches the RegEx Expression.
When omitted, everything is copied.</source>
        <translation>Формальний вираз. Копіювати до буфера обміну даними лише те, що відповідає
формальному виразу. Якщо не вказано, буде скопійовано усі дані.</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Налаштування</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Захоплення знімків</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Завантаження на Imgur</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Основне</translation>
    </message>
    <message>
        <source>Annotator</source>
        <translation>Параметри анотатору</translation>
    </message>
    <message>
        <source>HotKeys</source>
        <translation>Гарячі клавіші</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Вивантажувач</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Вивантажувач скриптів</translation>
    </message>
    <message>
        <source>Saver</source>
        <translation>Зберігач</translation>
    </message>
    <message>
        <source>Stickers</source>
        <translation>Стікери</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Обрізання області</translation>
    </message>
    <message>
        <source>Tray Icon</source>
        <translation>Піктограма у лотку</translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation>Водяний знак</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Дії</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>Вивантажувач FTP</translation>
    </message>
</context>
<context>
    <name>SnippingAreaResizerInfoText</name>
    <message>
        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
        <translation>Змініть розміри позначеного прямокутника за допомогою елементів керування або пересуньте його перетягуванням ділянки.</translation>
    </message>
    <message>
        <source>Use arrow keys to move the selection.</source>
        <translation>Скористайтеся клавішами зі стрілками для пересування позначеного.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
        <translation>Скористайтеся клавішами зі стрілками разом із Ctrl для пересуванян верхнього лівого кута.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
        <translation>Скористайтеся клавішами зі стрілками разом із Alt для пересування нижнього правого кута.</translation>
    </message>
    <message>
        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
        <translation>Підтвердьте позначення натисканням Enter/Return або скасуйте дію натисканням Esc.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Це повідомлення можна вимкнути у параметрах програми.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSelectorInfoText</name>
    <message>
        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
        <translation>Натисніть кнопку миші і перетягніть, щоб позначити прямокутну ділянку, або натисніть Esc, щоб вийти.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to resize selection after selecting.</source>
        <translation>Утримуйте натиснутою клавішу Ctrl, щоб змінити розміри ділянки після позначення.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
        <translation>Утримйте натиснутою клавішу Ctrl, щоб запобігти зміні розмірів після позначення.</translation>
    </message>
    <message>
        <source>Operation will be canceled after 60 sec when no selection made.</source>
        <translation>Дію буде скасовано, якщо протягом 60 секунд нічного не буде позначено.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Це повідомлення можна вимкнути у параметрах програми.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSettings</name>
    <message>
        <source>Freeze Image while snipping</source>
        <translation>Заморозити зображення на час обрізання</translation>
    </message>
    <message>
        <source>When enabled will freeze the background while
selecting a rectangular region. It also changes
the behavior of delayed screenshots, with this
option enabled the delay happens before the
snipping area is shown and with the option disabled
the delay happens after the snipping area is shown.
This feature is always disabled for Wayland and always
enabled for MacOs.</source>
        <translation>Якщо увімкнено, програма заморозить тло при
позначенні прямокутної ділянки. Параметр також
змінює поведінку при створенні відкладених знімків —
якщо увімкнено цей параметр, програма робитиме
паузу перед тим, як показувати вирізану область, а
якщо параметр вимкнено — після показу вирізаної
області. Цю можливість завжди вимкнено у Wayland
і завжди увімкнено у MacOs.</translation>
    </message>
    <message>
        <source>Show magnifying glass on snipping area</source>
        <translation>Показувати лупу під час вирізання ділянки</translation>
    </message>
    <message>
        <source>Show a magnifying glass which zooms into
the background image. This option only works
with &apos;Freeze Image while snipping&apos; enabled.</source>
        <translation>Показувати збільшувальне скло, яке дає змогу
наблизити фонове зображення. Цей пункт
працюватиме, лише якщо ввімкнено замороження зображення.</translation>
    </message>
    <message>
        <source>Show Snipping Area rulers</source>
        <translation>Показувати лінійки області вирізання</translation>
    </message>
    <message>
        <source>Horizontal and vertical lines going from
desktop edges to cursor on snipping area.</source>
        <translation>Показувати горизонтальну та вертикальну лінії,
які відходять від краю екрана до вказівника миші
під час позначення області знімка.</translation>
    </message>
    <message>
        <source>Show Snipping Area position and size info</source>
        <translation>Показувати інформацію щодо позиції і розміру вирізаної області</translation>
    </message>
    <message>
        <source>When left mouse button is not pressed the position
is shown, when the mouse button is pressed,
the size of the select area is shown left
and above from the captured area.</source>
        <translation>Якщо ліву кнопку миші не натиснуто, буде
показано позицію. Якщо ліву кнопку миші
натиснуто, ліворуч вгорі захопленої області
буде показано її розміри.</translation>
    </message>
    <message>
        <source>Allow resizing rect area selection by default</source>
        <translation>Типово дозволити зміну розмірів прямокутної позначеної ділянки</translation>
    </message>
    <message>
        <source>When enabled will, after selecting a rect
area, allow resizing the selection. When
done resizing the selection can be confirmed
by pressing return.</source>
        <translation>Якщо позначено, після вибору прямокутної
ділянки буде уможливлено зміну її розмірів.
Зміну розмірів може бути підтверджено
натисканням клавіші Enter.</translation>
    </message>
    <message>
        <source>Show Snipping Area info text</source>
        <translation>Показати інформаційний текст області вирізання</translation>
    </message>
    <message>
        <source>Snipping Area cursor color</source>
        <translation>Колір вказівника під час вирізання області</translation>
    </message>
    <message>
        <source>Sets the color of the snipping area cursor.</source>
        <translation>Встановлює колір вказівника при вирізанні ділянки.</translation>
    </message>
    <message>
        <source>Snipping Area cursor thickness</source>
        <translation>Товщина вказівника при вирізанні ділянки</translation>
    </message>
    <message>
        <source>Sets the thickness of the snipping area cursor.</source>
        <translation>Встановлює товщину вказівника області обрізання.</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Обрізання області</translation>
    </message>
    <message>
        <source>Snipping Area adorner color</source>
        <translation>Орнаментальний колір області обрізання</translation>
    </message>
    <message>
        <source>Sets the color of all adorner elements
on the snipping area.</source>
        <translation>Встановлює колір усіх елементів орнаменту
області обрізання.</translation>
    </message>
    <message>
        <source>Snipping Area Transparency</source>
        <translation>Прозорість області обрізання</translation>
    </message>
    <message>
        <source>Alpha for not selected region on snipping area.
Smaller number is more transparent.</source>
        <translation>Рівень прозорості для непозначеної ділянки області обрізання.
Менше значення — прозоріша ділянка.</translation>
    </message>
</context>
<context>
    <name>StickerSettings</name>
    <message>
        <source>Up</source>
        <translation>↑</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>↓</translation>
    </message>
    <message>
        <source>Use Default Stickers</source>
        <translation>Використовувати типові стікери</translation>
    </message>
    <message>
        <source>Sticker Settings</source>
        <translation>Параметри стікерів</translation>
    </message>
    <message>
        <source>Vector Image Files (*.svg)</source>
        <translation>файли векторних зображень (*.svg)</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Add Stickers</source>
        <translation>Додати наліпки</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Show Editor</source>
        <translation>Показати редактор</translation>
    </message>
</context>
<context>
    <name>TrayIconSettings</name>
    <message>
        <source>Use Tray Icon</source>
        <translation>Піктограма у лотку</translation>
    </message>
    <message>
        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
Change requires restart.</source>
        <translation>Якщо позначено, програма додасть піктограму лотка на панель задач, якщо у засобі керування вікнами операційної системи передбачено її підтримку.
Зміна потребує перезапуску програми.</translation>
    </message>
    <message>
        <source>Minimize to Tray</source>
        <translation>Згорнути до лотка</translation>
    </message>
    <message>
        <source>Start Minimized to Tray</source>
        <translation>Запускати згорнутою до лотка</translation>
    </message>
    <message>
        <source>Close to Tray</source>
        <translation>Закривати до лотка</translation>
    </message>
    <message>
        <source>Show Editor</source>
        <translation>Показати редактор</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Захопити</translation>
    </message>
    <message>
        <source>Default Tray Icon action</source>
        <translation>Типова дія для піктограми лотка</translation>
    </message>
    <message>
        <source>Default Action that is triggered by left clicking the tray icon.</source>
        <translation>Типова дія, яку буде виконано у відповідь на клацання лівою кнопкою миші на піктограмі у лотку.</translation>
    </message>
    <message>
        <source>Tray Icon Settings</source>
        <translation>Параметри піктограми лотка</translation>
    </message>
    <message>
        <source>Use platform specific notification service</source>
        <translation>Скористатися специфічною для платформи службою сповіщень</translation>
    </message>
    <message>
        <source>When enabled will use try to use platform specific notification
service when such exists. Change requires restart to take effect.</source>
        <translation>Якщо увімкнено, програма спробує скористатися специфічною для платформи
службою сповіщень, якщо така існує. Для набуття чинності змінами програму слід буде перезапустити.</translation>
    </message>
    <message>
        <source>Display Tray Icon notifications</source>
        <translation>Сповіщення з піктограми у лотку</translation>
    </message>
</context>
<context>
    <name>UpdateWatermarkOperation</name>
    <message>
        <source>Select Image</source>
        <translation>Вибрати зображення</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>файли зображень</translation>
    </message>
</context>
<context>
    <name>UploadOperation</name>
    <message>
        <source>Upload Script Required</source>
        <translation>Потрібен скрипт вивантаження</translation>
    </message>
    <message>
        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
        <translation>Будь ласка, додайте скрипт вивантаження за допомогою пункту меню «Налаштування &gt; Параметри &gt; Скрипт вивантаження»</translation>
    </message>
    <message>
        <source>Capture Upload</source>
        <translation>Вивантаження захопленого зображення</translation>
    </message>
    <message>
        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
        <translation>Ви наказали програмі вивантажити зображення на віддалений сервер. Хочете зробити саме це?</translation>
    </message>
</context>
<context>
    <name>UploaderSettings</name>
    <message>
        <source>Ask for confirmation before uploading</source>
        <translation>Питати підтвердження перед вивантаженням</translation>
    </message>
    <message>
        <source>Uploader Type:</source>
        <translation>Тип вивантажувача:</translation>
    </message>
    <message>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <source>Script</source>
        <translation>Скрипт</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Вивантажувач</translation>
    </message>
    <message>
        <source>FTP</source>
        <translation>FTP</translation>
    </message>
</context>
<context>
    <name>VersionTab</name>
    <message>
        <source>Version</source>
        <translation>Версія</translation>
    </message>
    <message>
        <source>Build</source>
        <translation>Збірка</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>Використовуємо:</translation>
    </message>
</context>
<context>
    <name>WatermarkSettings</name>
    <message>
        <source>Watermark Image</source>
        <translation>Зображення водяного знаку</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Оновити</translation>
    </message>
    <message>
        <source>Rotate Watermark</source>
        <translation>Повернути водяний знак</translation>
    </message>
    <message>
        <source>When enabled, Watermark will be added with a rotation of 45°</source>
        <translation>Якщо позначено, водяний знак буде додано із обертанням на 45°</translation>
    </message>
    <message>
        <source>Watermark Settings</source>
        <translation>Параметри водяного знаку</translation>
    </message>
</context>
</TS>
